@@ -1,9 +1,11 @@
 package Data::Fetch;
 
-use 5.12.0;	# Threads before that are apparently not good
+# use 5.12.0;	# Threads before that are apparently not good
+use 5.10.0;	# Earliest version that Coro works with
 use strict;
 use warnings;
-use threads;
+use Coro;
+# use threads;
 
 =head1 NAME
 
@@ -11,11 +13,11 @@ Data::Fetch - give advance warning that you'll be needing a value
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -44,7 +46,7 @@ sub new {
 
 	return unless(defined($class));
 
-	return bless { values => {} }, $class;
+	return bless { }, $class;
 }
 
 =head2 prime
@@ -71,18 +73,23 @@ sub prime {
 	if($self->{values}->{$object}) {
 		return $self;
 	}
-	$self->{values}->{$object}->{thread} = threads->create(sub {
-		my $o = shift;
-		my $m = shift;
-		my $rc;
-		if(my $a = $args{'arg'}) {
-			$rc = eval '$o->$m($a)';
-		} else {
-			$rc = eval '$o->$m()';
+	# $self->{values}->{$object}->{thread} = threads->create(sub {
+		# my $o = shift;
+		# my $m = shift;
+		# if(my $a = shift) {
+			# return eval '$o->$m($a)';
+		# }
+		# return eval '$o->$m()';
+	# }, $args{'object'}, $args{'message'}, $args{'arg'});
+
+	$self->{values}->{$object}->{thread} = async {
+		my $o = $args{object};
+		my $m = $args{message};
+		if(my $a = $args{arg}) {
+			return eval '$o->$m($a)';
 		}
-		die $@ if $@;
-		return $rc;
-	}, $args{'object'}, $args{'message'});
+		return eval '$o->$m()';
+	};
 
 	return $self;	# Easily prime lots of values in one call
 }
@@ -110,6 +117,7 @@ sub get {
 	if($self->{values}->{$object}->{thread}) {
 		my $rc = $self->{values}->{$object}->{thread}->join();
 		delete $self->{values}->{$object}->{thread};
+		# $self->{values}->{$object}->{thread} = undef;	# ????
 		return $self->{values}->{$object}->{value} = $rc;
 	}
 	die "Need to prime before getting";
@@ -123,9 +131,9 @@ sub DESTROY {
 
 	return unless($self->{values});
 
-	foreach my $o(values $self->{values}) {
+	foreach my $o(values %{$self->{values}}) {
 		if($o->{thread}) {
-			$o->{thread}->detach();
+			# $o->{thread}->detach();
 			delete $o->{thread};
 			delete $o->{value};
 		}
